<?php

namespace Drupal\flush_single_image\Commands;

use Drush\Commands\DrushCommands;
use Drupal\flush_single_image\FlushSingleImage;

/**
 * Class FlushSingleImageCommands.
 */
class FlushSingleImageCommands extends DrushCommands {

  /**
   * @var \Drupal\flush_single_image\FlushSingleImage
   */
  protected $flushSingleImage;

  /**
   * @param \Drupal\flush_single_image\FlushSingleImage $flush_single_image
   */
  public function __construct(FlushSingleImage $flush_single_image) {
    $this->flushSingleImage = $flush_single_image;
  }

  /**
   * Flush Single Image
   *
   * @param string $path
   * The image URI to flush image styles for. Provide relative path make sure
   *   start with the public:// E.g 'public://assets/foo/bar/image.jpg'
   *
   * @command flush_single_image
   * @bootstrap full
   * @aliases flush-sim
   * @option check-styles
   * Check if there are images styles available to cache first.
   *
   * @usage flush_single_image:flush
   */
  public function flush($path, $options = [' ' => FALSE]) {
    if (!file_exists($path)) {
      return $this->io()
        ->error(t('Provided path: @path is not vaild. Please make sure you provide valid path.', ['@path' => $path]));
    }

    $available_paths = $this->flushSingleImage->getStylePaths($path);
    if (empty($available_paths)) {
      return $this->io()
        ->success(t('No cached image found for @path.', ['@path' => $path]));
    }

    $delete = FALSE;
    if ($options['check-styles']) {
      foreach ($available_paths as $available_path) {
        $this->io()
          ->success(t('Available path @path.', ['@path' => $available_path]));
      }
      $delete = $this->io()->confirm('Flush Image Style(s)');
    }

    // Cancel flush
    if (!$delete && $options['check-styles']) {
      return $this->io()->success(t('Flush Image Styles cancelled.'));
    }

    // Flush all available image styles
    $paths = $this->flushSingleImage->flush($path);
    foreach ($paths as $path) {
      $this->io()->success(t('Flushed @path', ['@path' => $path]));
    }
    return $this->io()
      ->success(t('Flushed all image styles for @path', ['@path' => $path]));
  }

}
